import logging

from django.core.management.base import BaseCommand
from django.db import IntegrityError, transaction

from gaby.biopic import merge

logger = logging.getLogger(__name__)


class Command(BaseCommand):
    help = "Merge ABP database into Gaby"

    def add_arguments(self, parser):
        parser.add_argument(
            '--commit',
            '-c',
            dest='commit',
            action='store_true',
            default=False,
            help='actually make change (default is dryrun)',
        )

    def handle(self, *args, **options):
        logger.info(
            "Begin of operations - {}dryrun".format(
                "NOT " if options['commit'] else ""
            )
        )
        try:
            with transaction.atomic():
                merge.run()
                if not options['commit']:
                    raise IntegrityError('dry_run')
        except IntegrityError as err:
            if 'dry_run' in err.args:
                self.stdout.write(
                    self.style.HTTP_NOT_MODIFIED(
                        "DRY RUN - no change in database"
                    )
                )
            else:
                raise
        else:
            self.stdout.write(
                self.style.WARNING("REAL RUN - changes committed in database")
            )
        logger.info(
            "End of operations - {}dryrun".format(
                "NOT " if options['commit'] else ""
            )
        )
