from django.core.management.base import BaseCommand
from django.urls import reverse

from gaby.biopic.utils import (
    BpStructureCache,
    CommuneCache,
    PersonneCache,
    StructureCache,
)

GABY_PREFIX = 'https://bio-hdf.sloli.fr/gaby'

MODEL_MTX = {  # ModelName: ModelCache, use get_admin_url()
    'Structure': (StructureCache, True),
    'BpStructure': (BpStructureCache, False),
    'Commune': (CommuneCache, True),
    'Personne': (PersonneCache, True),
}


class Command(BaseCommand):
    help = (
        "Check dupes based on similary name."
        "available for models: {}".format(",".join(MODEL_MTX.keys()))
    )

    def add_arguments(self, parser):
        parser.add_argument('model', help='search dupes in this model')

    def get_url(self, model, use_get_admin_url):
        if not use_get_admin_url:
            return model.url()
        return GABY_PREFIX + reverse(
            'admin:{0}_{1}_change'.format(
                model._meta.app_label, model.__class__.__name__.lower()
            ),
            args=[model.pk],
        )

    def handle(self, *args, **options):
        cpt = 0
        sub_cpt = 0
        cache_class, use_gau = MODEL_MTX.get(options['model'], (None, None))
        if cache_class is None:
            print("Model {} inconnu".format(options['model']))
            print(
                "Les models valides sont {}".format(
                    ", ".join(MODEL_MTX.keys())
                )
            )
            return
        model_cache = cache_class()
        for key, val_list in model_cache.get_dupes():
            print("## {}".format(key))
            for val in val_list:
                print("  {}".format(self.get_url(val, use_gau)))
                sub_cpt += 1
            cpt += 1
        print("# {} doublons ({} lignes)".format(cpt, sub_cpt))
