# -*- coding: utf-8 -*-
import datetime

import django.forms as forms
from django.forms.models import inlineformset_factory

import gaby.contacts.models as cmodels
import gaby.references.models as rmodels


class BaseDonneesBioAdhForm(forms.ModelForm):
    class Meta:
        model = cmodels.DonneesBio
        exclude = (
            'date_collecte',
            'date_validation',
            'technicien',
            'agriculteur_bio',
            'annee',
            'remarques',
            'com_ca_total',
            'com_pct_ca_bio',
            'ass_total_bio',
            'ass_total',
        )

    def __init__(self, *args, **kwargs):
        self.struct = kwargs.pop('struct', None)
        super(BaseDonneesBioAdhForm, self).__init__(*args, **kwargs)

    def save(self, *args, **kwargs):
        "ensure that data is set to be validate again"
        sup = super(BaseDonneesBioAdhForm, self)
        self.instance.date_validation = None
        self.instance.date_modification = datetime.date.today()
        if self.instance.agriculteur_bio_id is None:
            self.instance.agriculteur_bio = self.struct
        return sup.save(*args, **kwargs)


class AssolementModelForm(forms.ModelForm):
    class Meta:
        model = cmodels.Assolement
        exclude = []

    def __init__(self, *args, **kwargs):
        super(AssolementModelForm, self).__init__(*args, **kwargs)
        self.fields['culture'].choices = rmodels.regroup_culture_cat()


AssolementFormSet = inlineformset_factory(
    cmodels.DonneesBio,
    cmodels.Assolement,
    form=AssolementModelForm,
    extra=0,
    exclude=[],
)
CommercialisationFormSet = inlineformset_factory(
    cmodels.DonneesBio, cmodels.Commercialisation, extra=0, exclude=[]
)
TransformationFormSet = inlineformset_factory(
    cmodels.DonneesBio, cmodels.Transformation, extra=0, exclude=[]
)


class DonneesBioAdhForm(BaseDonneesBioAdhForm):
    pass


class DonneesBioAddAdhForm(BaseDonneesBioAdhForm):
    pass


# EOF
