# -*- coding: utf-8 -*-
from django.contrib.auth import models as am
from django.test import TestCase
from django.urls import reverse

from gaby.contacts import models as cm
from gaby.contacts.settings_messages import AVERTISSEMENT_MESSAGE as w_msg
from gaby.contacts.tests.utils import cfty, mfty
from gaby.references import models as rm


class ValAdminStructure(TestCase):
    def setUp(self):
        self.messagePersonne = w_msg["message_personne_manquante"]
        self.messageProjet = w_msg["message_projet_bio_manquant"]
        self.usr1 = am.User.objects.create_superuser('usr1', '', 'mdp')
        self.usr1.save()
        self.client.login(username=self.usr1.username, password='mdp')
        self.fjur = rm.FormeJuridique()
        self.fjur.save()
        self.data = {
            'adhesiongabnor_set-TOTAL_FORMS': '0',
            'adhesiongabnor_set-INITIAL_FORMS': '0',
            'adhesiongabnor_set-MAX_NUM_FORMS': '',
            'personne_set-TOTAL_FORMS': '0',
            'personne_set-INITIAL_FORMS': '0',
            'personne_set-MAX_NUM_FORMS': '',
            'projetbio_set-TOTAL_FORMS': '0',
            'projetbio_set-INITIAL_FORMS': '0',
            'projetbio_set-MAX_NUM_FORMS': '',
            'rdvpersonnemorale_set-TOTAL_FORMS': '0',
            'rdvpersonnemorale_set-INITIAL_FORMS': '0',
            'rdvpersonnemorale_set-MAX_NUM_FORMS': '',
            'activitestructure_set-TOTAL_FORMS': '0',
            'activitestructure_set-INITIAL_FORMS': '0',
            'activitestructure_set-MAX_NUM_FORMS': '',
            'f_juridique': str(self.fjur.id),
            'designation': 'test',
            'visibilite': 'personne',
        }
        self.data_projet = {
            'projetbio_set-TOTAL_FORMS': '1',
            'projetbio_set-0-pond_savoirfaire': '-1',
            'projetbio_set-0-pond_motivation': '0',
            'projetbio_set-0-pond_entourage': '0',
            'projetbio_set-0-pond_foncier': '0',
            'projetbio_set-0-pond_materiel': '0',
            'projetbio_set-0-pond_reglementation': '0',
            'projetbio_set-0-pond_commercialisation': '0',
            'projetbio_set-0-pond_financement': '0',
            'projetbio_set-0-pond_maindoeuvre': '0',
            'projetbio_set-0-installation_bio': True,
        }
        self.data_personne = {
            'personne_set-TOTAL_FORMS': '1',
            'personne_set-0-nom': 'testin',
            'personne_set-0-prenom': 'teston',
            'personne_set-0-date_naissance': '2000-01-01',
        }

    def test_structure_personne(self):
        """Une structure de type agri ou agri bio devrait
        avoir une personne physique affiliée"""

        # Structure agri sans personne affiliée avec avertissement
        data = self.data.copy()
        data['statutbio'] = '1'
        path = reverse('admin:contacts_structure_add')
        response = self.client.post(path, data, follow=True)
        msg2 = list()
        for message in list(response.context['messages']):
            msg2.append(message.message)
        self.assertNotEqual(len(msg2), 0, "Erreur lors de l'enregistrement")
        self.assertIn(self.messagePersonne, msg2)

        # Structure agri avec personne affiliée sans avertissement
        data.update(self.data_personne)
        path = reverse('admin:contacts_structure_add')
        response = self.client.post(path, data, follow=True)
        msg2 = list()
        for message in list(response.context['messages']):
            msg2.append(message.message)
        self.assertNotEqual(len(msg2), 0, "Erreur lors de l'enregistrement")
        self.assertNotIn(self.messagePersonne, msg2)

        # Structure simple sans personne affiliée sans avertissement
        data = self.data.copy()
        data['statutbio'] = 0
        path = reverse('admin:contacts_structure_add')
        response = self.client.post(path, data, follow=True)
        msg2 = list()
        for message in list(response.context['messages']):
            msg2.append(message.message)
        self.assertNotEqual(len(msg2), 0, "Erreur lors de l'enregistrement")
        self.assertNotIn(self.messagePersonne, msg2)

    def test_structure_projet(self):
        """ Une structure de type agri bio devrait
        avoir un projet bio avec date d'engagement OC"""

        # Structure agri sans projet sans avertissement
        data = self.data.copy()
        data['statutbio'] = 1
        path = reverse('admin:contacts_structure_add')
        response = self.client.post(path, data, follow=True)
        msg2 = list()
        for message in list(response.context['messages']):
            msg2.append(message.message)
        self.assertNotEqual(len(msg2), 0, "Erreur lors de l'enregistrement")
        self.assertNotIn(self.messageProjet, msg2)

        # Structure agri bio sans projet avec avertissement
        data = self.data.copy()
        data['statutbio'] = 2
        path = reverse('admin:contacts_structure_add')
        response = self.client.post(path, data, follow=True)
        msg2 = list()
        for message in list(response.context['messages']):
            msg2.append(message.message)
        self.assertNotEqual(len(msg2), 0, "Erreur lors de l'enregistrement")
        self.assertIn(self.messageProjet, msg2)

        # Structure agri bio avec projet sans date avec avertissement
        data.update(self.data_projet)
        path = reverse('admin:contacts_structure_add')
        response = self.client.post(path, data, follow=True)
        msg2 = list()
        for message in list(response.context['messages']):
            msg2.append(message.message)
        self.assertNotEqual(len(msg2), 0, "Erreur lors de l'enregistrement")
        self.assertIn(self.messageProjet, msg2)

        # Structure agri bio avec projet et date sans avertissement
        data['projetbio_set-0-date_engagement_oc'] = '2000-01-01'
        path = reverse('admin:contacts_structure_add')
        response = self.client.post(path, data, follow=True)
        msg2 = list()
        for message in list(response.context['messages']):
            msg2.append(message.message)
        self.assertNotEqual(len(msg2), 0, "Erreur lors de l'enregistrement")
        self.assertNotIn(self.messageProjet, msg2)

    def test_structure_wo_sau(self):
        "struct(agri_bio) should warn if SAU is not filled"
        data = self.data.copy()
        data['statutbio'] = 1
        path = reverse('admin:contacts_structure_add')
        response = self.client.post(path, data, follow=True)
        m_list = [elm.message for elm in response.context['messages']]
        self.assertTrue(len(m_list) == 3, "Erreur lors de l'enregistrement")
        self.assertIn(w_msg["sau_vide"], m_list)
        self.assertIn(w_msg["message_personne_manquante"], m_list)
        # add donnees bio with assolement
        cm.Structure.objects.get(designation='test')

    def test_structure_w_sau(self):
        "struc(agri_bio) shouldn't warn if SAU is filled"
        struct = mfty(
            cm.Structure,
            {
                'f_juridique': self.fjur,
                'designation': 'test',
                'statutbio': 1,
                'utilisateur_derniere_modification': self.usr1,
            },
        )
        struct.full_clean()
        struct.save()
        dbio = cfty(cm.DonneesBio, {'annee': 2000, 'agriculteur_bio': struct})
        c_cult = cfty(rm.CategorieCulture, {'designation': "test_cat"})
        cult = cfty(
            rm.Culture, {'designation': "test_cat", 'categorie_cul': c_cult}
        )
        ass = mfty(
            cm.Assolement,
            {'culture': cult, 'surface_c1': 2, 'donneesbio': dbio},
        )
        ass.full_clean()
        ass.save()
        data = self.data.copy()
        data.update({'statutbio': 1, 'f_juridique': str(self.fjur.id)})
        path = reverse('admin:contacts_structure_change', args=[struct.id])
        response = self.client.post(path, data, follow=True)
        m_list = [elm.message for elm in response.context['messages']]
        self.assertTrue(len(m_list) == 2, "Erreur lors de l'enregistrement")
        self.assertNotIn(w_msg["sau_vide"], m_list)
        self.assertIn(w_msg["message_personne_manquante"], m_list)


# EOF
