# -*- coding: utf-8 -*-
from django.contrib.auth import models as am
from django.core.exceptions import ValidationError
from django.test import TestCase

from gaby.contacts import models as cm
from gaby.contacts.tests.utils import cfty, mfty
from gaby.references import models as rm


class ValCommercialisation(TestCase):
    def setUp(self):
        self.usr1 = am.User.objects.create_user('usr1')
        self.fjur = rm.FormeJuridique()
        self.fjur.save()
        self.i_pm = {
            'date_creation': '2014-10-01',
            'date_derniere_modification': '2014-10-02',
            'utilisateur_derniere_modification': self.usr1,
            'f_juridique': self.fjur,
            'designation': "test",
            'statutbio': 2,
        }
        self.agriculteur = cfty(cm.Structure, self.i_pm)
        self.i_d = {'agriculteur_bio': self.agriculteur}

    def test_commercialisation_get_ch_aff(self):
        """ La méthode get_ch_aff doit renvoyer 0 si il n'y a pas de
        chiffre d'affaire indiqué"""
        # Pas de CA d'indiqué
        donnees = cfty(cm.DonneesBio, self.i_d)
        commercialisation = mfty(cm.Commercialisation, {'donneesbio': donnees})
        ca = commercialisation.get_ch_aff()
        self.assertEqual(ca, 0)
        # CA indiqué
        commercialisation.ch_aff = 100
        ca = commercialisation.get_ch_aff()
        self.assertEqual(ca, 100)

    def test_commercialisation_get_total_ca_for_all_comm(self):
        """ La méthode get_total_ca_for_all_comm doit renvoyer le chiffre
        d'affaire total et le ratio de chiffre d'affaire bio"""
        # Total sans chiffre d'affaire
        donnees = cfty(cm.DonneesBio, self.i_d)
        commercialisation = mfty(cm.Commercialisation, {'donneesbio': donnees})
        result = commercialisation.get_total_ca_for_all_comm()
        self.assertEqual(result, (0, 0))
        # Total avec 2 chiffres d'affaire bio et non bio
        cfty(
            cm.Commercialisation,
            {'donneesbio': donnees, 'ch_aff': 100, 'bio': True},
        )
        commercialisation2 = cfty(
            cm.Commercialisation,
            {'donneesbio': donnees, 'ch_aff': 100, 'bio': False},
        )
        result = commercialisation2.get_total_ca_for_all_comm()
        self.assertEqual(result, (200, 50))

    def test_commercialisation_clean(self):
        """ Le champ bio doit être renseigné"""
        # Commercialisation sans le champ bio renseigné en erreur
        donnees = cfty(cm.DonneesBio, self.i_d)
        commercialisation = mfty(cm.Commercialisation, {'donneesbio': donnees})
        self.assertRaises(ValidationError, commercialisation.full_clean)
        #  Commercialisation avec le champ bio renseigné sans erreur
        commercialisation.bio = True
        commercialisation.full_clean()
