from django.urls import reverse

import pytest

from ..views import gen_stat, small_render
from .factories import ProjetBioFactory, StructureFactory


class TestTestView:
    def test_test_view(self, client):
        resp = client.get(reverse('test_view'))
        assert resp.status_code == 200

    @pytest.mark.parametrize(
        ['code', 'exp_code'], [['404', 404], ['403', 403]]
    )
    def test_test_view_code(self, client, code, exp_code):
        resp = client.get(reverse('test_view', kwargs={'code': code}))
        assert resp.status_code == exp_code

    def test_test_view_500(self, client):
        try:
            client.get(reverse('test_view', kwargs={'code': 500}))
        except ValueError:
            pass
        else:
            assert False

    def test_test_view_warning(self, client, caplog):
        client.get(reverse('test_view', kwargs={'code': 'warning'}))
        assert "testé: warning" in caplog.messages


class TestHelper:
    @pytest.mark.parametrize(
        ['model_factory', 'field_name', 'value', 'exp_value'],
        [
            (StructureFactory, 'designation', 'bonjour', 'bonjour'),
            (StructureFactory, 'statutbio', 2, 'bio'),
            (StructureFactory, 'cat_act_agriculteur', True, 'oui'),
            (StructureFactory, 'cat_act_agriculteur', False, 'non'),
            (ProjetBioFactory, 'etude_demandee', None, 'inconnu'),
            (ProjetBioFactory, 'etude_demandee', True, 'oui'),
            (ProjetBioFactory, 'etude_demandee', False, 'non'),
        ],
    )
    def test_small_render(self, model_factory, field_name, value, exp_value):
        field = model_factory._meta.model._meta.get_field(field_name)
        struct = model_factory.build(**{field_name: value})
        assert small_render(struct, field, value) == exp_value

    @pytest.mark.django_db
    def test_gen_stat(self):
        StructureFactory.create(statutbio=0)
        StructureFactory.create(statutbio=1)
        StructureFactory.create(statutbio=2)
        assert gen_stat() == {'nb_total': 3, 'nb_agri': 2, 'nb_agri_bio': 1}
