# -*- coding: utf-8 -*-
from django.contrib import admin

import gaby.references.models as ref_models


class AdminPRA(admin.ModelAdmin):
    "petite region agricole"
    list_display = ('nom', 'code', 'grande_region', 'departement')
    list_filter = ('departement',)


class AdminArrondissement(admin.ModelAdmin):
    list_display = ('nom', 'departement')
    list_filter = ('departement',)


class AdminCommune(admin.ModelAdmin):
    list_display = (
        'nom',
        'code_insee',
        'code_postal',
        'arrondissement',
        'petite_region',
        'territoire',
        'agence_eau',
        'enjeu_eau',
    )
    list_filter = ('agence_eau', 'enjeu_eau', 'territoire', 'petite_region')
    search_fields = ('nom',)


class AdminDesignationObjet(admin.ModelAdmin):
    "Personnalisation de l'admin des tables basées sur DesignationObjet."
    search_fields = ('designation',)


class AdminEtiquette(AdminDesignationObjet):
    "Personnalisation de l'admin du modèle Etiquette."
    list_display = ('designation', 'description')
    search_fields = ('designation',)


class AdminNomObjet(admin.ModelAdmin):
    "Personnalisation de l'admin des tables basées sur NomObjet."
    pass


class AdminCulture(admin.ModelAdmin):
    "Personnalisation de l'admin du modèle Culture."
    list_display = ('designation', 'categorie_cul', 'indice_ordre', 'enabled')
    list_editable = ('categorie_cul', 'indice_ordre', 'enabled')
    search_fields = ('categorie_cul__designation', 'designation')


def register_models(site):
    "Enregistrement des modèles dans un AdminSite passé en paramètre."
    site.register(ref_models.Etiquette, AdminEtiquette)
    site.register(ref_models.Territoire)
    site.register(ref_models.PublicCible)
    site.register(ref_models.PetiteRegionAgricole, AdminPRA)
    site.register(ref_models.Arrondissement, AdminArrondissement)
    site.register(ref_models.Commune, AdminCommune)

    #    site.register(ref_models.CategorieStructure, AdminDesignationObjet)
    site.register(ref_models.StatutCommercialisation, AdminDesignationObjet)
    site.register(ref_models.Laiterie, AdminNomObjet)
    site.register(ref_models.OrganismeDeCertification, AdminNomObjet)
    site.register(ref_models.StatutStructure, AdminDesignationObjet)
    site.register(ref_models.TypeService, AdminDesignationObjet)
    site.register(ref_models.Culture, AdminCulture)
    site.register(ref_models.CategorieCulture)
    site.register(ref_models.ClientCulture, AdminDesignationObjet)
    site.register(ref_models.Abattoir, AdminNomObjet)
    site.register(ref_models.AcheteurOeufs, AdminDesignationObjet)
    site.register(ref_models.Formation, AdminDesignationObjet)
    site.register(ref_models.TypeFormation, AdminDesignationObjet)
    site.register(ref_models.FormeJuridique, AdminDesignationObjet)
    site.register(ref_models.FinanceProg, AdminDesignationObjet)


# register_models(admin.site)
# EOF
