import re

import luhn

RE_BLANK = re.compile(r'[ _-]*')


class CheckSiret:
    """
    Usage:
    status_siret = CheckSiret('45383795700043')
    status_siret.get_verified_value()
    >>> '45383795700043'
    status_siret.is_siret
    >>> True
    status_siret.is_siren
    >>> True
    """

    is_siret = False
    is_siren = False

    def __init__(self, siret):
        self.siret = RE_BLANK.sub('', str(siret))
        self.siren = self.siret[:9]
        self.check()

    def check(self):
        self.check_siren()
        self.check_siret()

    def check_siret(self):
        if len(self.siret) != 14:
            return
        try:
            int(self.siret)
        except ValueError:
            pass  # peut etre une exception de type MONACOCONFO0013
        else:
            self.is_siret = luhn.verify(self.siret)  # cas general
            if not self.is_siret and self.siren == '356000000':  # cas la poste
                self.is_siret = (sum(map(int, self.siret)) % 5) == 0

    def check_siren(self):
        if len(self.siren) != 9:
            return
        try:
            int(self.siren)
        except ValueError:
            pass  # peut etre une exception de type MONACOCON
        else:
            self.is_siren = luhn.verify(self.siren)

    def get_verified_value(self):
        if self.is_siret:
            return self.siret
        elif self.is_siren:
            return self.siren
        return ''
