import pytest

from gaby.siret import CheckSiret


@pytest.mark.parametrize(
    ('input', 'output'),
    [
        ('', ''),
        ('45383795700043', '45383795700043'),
        ('453 -_ 837 957--00043', '45383795700043'),
        ('45383795700044', '45383795700044'),
        ('   453837957 - 0004 ', '4538379570004'),
    ],
)
def test_cleanup(input, output):
    assert CheckSiret(input).siret == output


@pytest.mark.parametrize(
    ('input', 'is_siren', 'is_siret', 'verified_value'),
    [
        ('', False, False, ''),
        ('SIREN6789', False, False, ''),
        ('SIRET678901234', False, False, ''),
        ('45383795700043', True, True, '45383795700043'),  # siret ok
        ('453837957', True, False, '453837957'),  # siren ok
        ('45383795700044', True, False, '453837957'),  # siret ko/siren ok
        ('35600000000048', True, True, '35600000000048'),  # siret poste siege
        ('35600000008486', True, True, '35600000008486'),  # siret poste agen
        ('35600000000049', True, False, '356000000'),  # siret ko poste siege
        ('35600000008485', True, False, '356000000'),  # siret ko poste agen
    ],
)
def test_check_siren_siret(input, is_siren, is_siret, verified_value):
    status_siret = CheckSiret(input)
    assert status_siret.is_siren == is_siren
    assert status_siret.is_siret == is_siret
    assert status_siret.get_verified_value() == verified_value
