"utilitaires simples sans dependance django"


class Cpt:
    """
    Cpt, un compteur permettant de voir la progression
    usage:
    total = len(ma_list)

    cpt = Cpt(msg, total, fd=None)
    for elm in ma_list:
       do_something(elm)
       cpt()
    cpt.last()  # optionnel:
    # si la boucle est allee jusqu'au bout le compteur finit avec un '\n'

    si fd n'est pas precise, c'est sys.stdout qui est utilise, il faut
    donc importer le module sys...
    """

    def __init__(self, msg="process", total=100, fd=None):
        self.msg = msg
        self.idx = 1
        self.total = total
        self.fd = fd
        if fd is None:
            import sys

            self.fd = sys.stdout

    def __call__(self):
        last_ch = '\r' if self.idx < self.total else '\n'
        self.fd.write(
            '{0}: {1}/{2}{3}'.format(self.msg, self.idx, self.total, last_ch)
        )
        self.fd.flush()
        self.idx += 1

    def last(self):
        if self.idx < self.total:
            self.fd.write('\n')
            self.fd.flush()


def regroup_choices(
    elm_list,
    get_elm_cat,
    blank=True,
    blank_label='---------',
    blank_value='',
    get_elm_id=lambda x: x.id,
    elm_disp=lambda x: str(x),  # noqa: F821
):
    """
    generic function to build a choice list regroup by category suitable for
    django:
    - elm_list: an iterable that is related to a category. This list
                must be sorted regarding category.
    - get_elm_cat: a function that extract category from elm
    - blank: like in a django field, if blank=True, display a 'empty' field,
             with label 'blank_label' and value 'blank_value'
    - get_elm_id: a function that extract elm id (elm.id by default)
    - elm_disp: a function that display elm (unicode(elm) by default)

    For example:
    a queryset of Foo with Foo.label as label and
    Foo.bar a foreign key to Bar and Bar.label
    what we want for a category.

    with the following:
    foo.id | foo.label | foo.bar.label
    2      | 'yopyop'  | 'cat1'
    3      | 'babar'   | 'cat1'
    22     | 'yop'     | None

    qs_elm = Elm.objects.order_by('bar__label', 'label')
    get_elm_cat = lambda x: x.bar.label if x.bar else 'N/A'

    regroup_choices(qs_elm, get_elm_cat)

    should return:
    [ ('', [ (None, '--------'), ], ),
      ('N/A', [ (22, 'yop'), ], ),
      ('cat1' [ (3, 'babar'),
                (2, 'yopyop'), ], )
    ]
    """

    choices = [('', ((blank_value, blank_label),))] if blank else []
    acc = []
    cat_cur, cat_prv, first_loop = None, None, True
    for elm in elm_list:
        cat_prv, cat_cur = cat_cur, get_elm_cat(elm)
        if cat_cur == cat_prv or first_loop:
            acc.append((get_elm_id(elm), elm_disp(elm)))
        else:
            choices.append((cat_prv, acc))
            acc = [(get_elm_id(elm), elm_disp(elm))]
        first_loop = False
    if not first_loop:
        choices.append((cat_cur, acc))
    return choices
