# Generated by Django 2.2.1 on 2019-05-21 16:25
import logging
import sys

from django.db import IntegrityError, migrations
from django.db.models import Count

from gaby.utils import Cpt

logger = logging.getLogger(__name__)

# References.TypeActivite.designation
# -> Contacts.ActiviteStructure.nom
MAP_ACT_PRINCIPAL = {
    "Autre élevage":             'autre_elevage',
    "Apiculture":                'apiculture',
    "Arboriculture":             'arboriculture',
    "Autre production végétale": 'autre_prod_veg',
    "Bovin lait":                'bovin_lait',
    "Bovin viande":              'bovin_viande',
    "Caprin":                    'caprin',
    "Fourrage":                  'fourrage',
    "Grande culture":            'grande_culture',
    "Lapin":                     'lapin',
    "Légume plein champ":        'legume_pl_champ',
    "Maraîchage":                'maraichage',
    "Ovin lait":                 'ovin_lait',
    "Ovin viande":               'ovin_viande',
    "Porcin":                    'porcin',
    "Poule pondeuse":            'poule_pondeuse',
    "PPAM":                      'ppam',
    "Viticulture":               'viticulture',
    "Volaille de chair":         'volaille_chair',
}

# References.AutreQualificatifExploitation.designation
# -> Contacts.ActiviteStructure
MAP_ACT_AUTRE = {
    "Ail":                  'maraichage',
    "Apiculture":           'apiculture',
    "Arbo basse tige":      'arboriculture',
    "Arbo haute tige":      'arboriculture',
    "Bovin lait":           'bovin_lait',
    "Bovin viande":         'bovin_viande',
    "Caprin":               'caprin',
    "Cervidé":              'autre_elevage',
    "Champignon":           'autre_prod_veg',
    "Conchyliculture":      'autre_elevage',
    "Cresson":              'maraichage',
    "Élevage de gibier":    'autre_elevage',
    "Endive":               'maraichage',
    "Équin":                'autre_elevage',
    "Escargot":             'autre_elevage',
    "Fourrage":             'fourrage',
    "Grande culture":       'grande_culture',
    "Herbager":             'autre_prod_veg',
    "Horticulture":         'autre_prod_veg',
    "Houblon":              'autre_prod_veg',
    "Lapin":                'lapin',
    "Légume ancien":        'maraichage',
    "Légume plein champ":   'legume_pl_champ',
    "Maraîchage":           'maraichage',
    "Ovin lait":            'ovin_lait',
    "Ovin viande":          'ovin_viande',
    "Pépinière":            'arboriculture',
    "Petit fruit":          'autre_prod_veg',
    "Plant":                'autre_prod_veg',
    "Pomme de terre":       'legume_pl_champ',
    "Porcin":               'porcin',
    "Poule pondeuse":       'poule_pondeuse',
    "Pousse de soja":       'autre_prod_veg',
    "PPAM":                 'ppam',
    "Raisin":               'viticulture',
    "Rhubarbe":             'autre_prod_veg',
    "Tabac":                'autre_prod_veg',
    "Viticulture":          'viticulture',
    "Volaille de chair":    'volaille_chair',
}


def bio_first(struct):
    # main activity bio only -> bio
    if (struct.type_activite_id and not struct.type_activite_pri_id):
        return True
    # main activity bio and conv:
    # -> bio only if bio and conv activity are the same
    if (
            struct.type_activite_id and struct.type_activite_pri_id
            and struct.type_activite_id == struct.type_activite_pri_id
    ):
        return True
    # otherwise, not bio first
    return False


def get_old_act_pri(struct):
    """return (main activity, is_bio) for old style activity"""
    prio_act = ('type_activite_pri', 'type_activite')  # conv then bio
    if bio_first(struct):
        prio_act = prio_act[::-1]
    act, is_bio = None, False
    for attr in prio_act:
        act = getattr(struct, attr, None)
        is_bio = (attr == 'type_activite')
        if act is not None:
            break
    return act, is_bio


def get_new_act_pri(struct):
    """ return (main activity, is_bio) for new style activity"""
    act, is_bio = None, False
    act_qs = struct.activitestructure_set.all()
    if bool(act_qs):
        act = act_qs.first()
        is_bio = (act.activite_bio == 2)
    return act, is_bio


def get_list_act(struct):
    if struct.activitestructure_set.exists():
        logger.warning(
            'Structure {} already got activites - let it alone'
            .format(str(struct))
        )
        return []
    list_act = []
    list_compl = []
    attr_list = (
        ('type_activite_pri', 'qual_compl_conv'),  # conventionnel
        ('type_activite', 'qual_compl'),  # bio
    )
    if bio_first(struct):  # si bio, on inverse l'ordre
        attr_list = attr_list[::-1]
    for attr_pri, attr_compl in attr_list:
        list_act.extend(get_act_principal(struct, attr_pri))
        list_act.extend(get_act_compl(struct, attr_compl))
    # remove dups
    key_set = set()
    list_act_distinct = []
    for elm in list_act:
        key = '{}-{}-{}'.format(
            elm['activite_bio'], elm['nom'], elm['precision']
        )
        if key not in key_set:
            list_act_distinct.append(elm)
            key_set.add(key)
    # curry act_list_distinct with position and structure_id
    for idx, elm in enumerate(list_act_distinct):
        elm.update({'position': idx, 'structure_id': struct.id})
    return list_act_distinct


def get_act_principal(struct, attr):
    act_pri = getattr(struct, attr)
    if act_pri and act_pri.designation:
        act_nom_brut = act_pri.designation
        act_nom = MAP_ACT_PRINCIPAL.get(act_nom_brut, 'autre')
        if act_nom == 'autre':
            logger.warning(
                "Check Structure {} ({}) is unrecognized".format(struct.id, attr)
            )
        act_precision = '' if act_nom else act_nom_brut
        act_bio = 2 if attr == 'type_activite' else 0
        return [{
            'nom': act_nom,
            'precision': act_precision,
            'activite_bio': act_bio,
        }]
    return []


def get_act_compl(struct, attr):
    list_compl = []
    act_compl_qs = getattr(struct, attr)
    for act_compl in act_compl_qs.all():
        act_nom_brut = act_compl.designation
        act_nom = MAP_ACT_AUTRE.get(act_nom_brut, 'autre')
        if not act_nom:
            logger.warning(
                "Check Structure {} ({}) is unrecognized".format(struct.id, attr)
            )
        act_precision = '' if act_nom_brut in MAP_ACT_PRINCIPAL else act_nom_brut
        act_bio = 2 if attr == 'qual_compl' else 0
        list_compl.append(
            {
                'nom': act_nom,
                'precision': act_precision,
                'activite_bio': act_bio,
            }
        )
    return list_compl


def check_data_structure(Structure):
    str_qs = Structure.objects.all()
    str_qs_no_act = str_qs.filter(
        type_activite__isnull=True, type_activite_pri__isnull=True
    )
    for struct in str_qs_no_act:
        if struct.activitestructure_set.exists():
            logger.warning(
                "Check structure({}) should not have 'ActiviteStructure'"
                " affiliated with".format(struct.id)
            )
    # balayer les structures ayant au moins une activite principale
    for struct in Structure.objects.exclude(
            type_activite__isnull=True,
            type_activite_pri__isnull=True
    ):
        old_act, old_act_bio = get_old_act_pri(struct)
        new_act, new_act_bio = get_new_act_pri(struct)
        if old_act is None or new_act is None:
            logger.error("Check - internal inconsistency struct.id={}".format(struct.id))
        old_act_name = old_act.designation
        new_act_name = new_act.get_nom_display()
        if (old_act_name, old_act_bio) != (new_act_name, new_act_bio):
            logger.warning(
                "Check structure({}) "
                "old[{}-{}] "
                "new[{}-{}]"
                .format(
                    struct.id, old_act_name, old_act_bio, new_act_name, new_act_bio
                )
            )


def check_data_activite_structure(ActiviteStructure):
    if ActiviteStructure.objects.filter(nom='').exists():
        logger.warning("Check ActiviteStructure with non initialized name exists")
    if ActiviteStructure.objects.filter(nom='autre').exists():
        logger.warning("Check ActiviteStructure with non matched name exists")
    # check for dupes, cf 'GROUP BY' black magic
    # https://gist.github.com/victorono/cd9d14b013487b8b22975512225c5b4c
    duplicates = (
        ActiviteStructure.objects.values(
            'structure', 'activite_bio', 'nom', 'precision'
        )
        .order_by().annotate(count_id=Count('id'))
        .filter(count_id__gt=1)
    )
    for dup in duplicates:
        logger.warning("Check Structure({}) got duplicates activity".format(dup['structure']))

def fill_all_structures(apps, schema_editor):
    Structure = apps.get_model('contacts.Structure')
    ActiviteStructure = apps.get_model('contacts.ActiviteStructure')
    logger.info(
        "** Begin data migration (activite) for {} structures".format(
            Structure.objects.count()
        )
    )
    str_qs = Structure.objects.all()
    cpt = Cpt("Structure", len(str_qs))
    sys.stdout.write('\n')
    for struct in str_qs:
        list_act = [ActiviteStructure(**elm) for elm in get_list_act(struct)]
        ActiviteStructure.objects.bulk_create(list_act)
        cpt()
    ## check if we fill it the right way
    logger.info("** Check data")
    check_data_activite_structure(ActiviteStructure)
    check_data_structure(Structure)
    logger.info(
        "** End data migration (activite) for {} structures".format(
            Structure.objects.count()
        )
    )

class Migration(migrations.Migration):

    dependencies = [
        ('contacts', '0013_ajout_table_activite_structure'),
    ]

    operations = [
        migrations.RunPython(fill_all_structures),
    ]
